Crate luct_scanner

Crate luct_scanner 

Certificate transparency auditing logic used by luCT firefox extension and CLI tool

Structs

Report
Scanner
The scanner holds the state that is necessary to perform audits as well as the auditing logic
ScannerConfig
Configuration values of the ScannerConfig.
ScannerConfigBuilder
Builder for ScannerConfig.
SctReport
SthReport
Validated
Wrapper around a type to indicate, that the contained value has been validated

Enums

ScannerError

Traits

ScannerImpl
Bundle trait for Scanner