pub struct Scanner<S: ScannerImpl> { /* private fields */ }Expand description
The scanner holds the state that is necessary to perform audits as well as the auditing logic
It is generic over ScannerImpl, which is a bundle trait containing implementations of Stores
and Clients.
Implementations
Sourceimpl<S: ScannerImpl> Scanner<S>
impl<S: ScannerImpl> Scanner<S>
pub async fn collect_report_pem( &self, data: &str, ) -> Result<Report, ScannerError>
pub async fn collect_report( &self, chain: Arc<CertificateChain>, ) -> Result<Report, ScannerError>
Sourceimpl<S: ScannerImpl> Scanner<S>
impl<S: ScannerImpl> Scanner<S>
pub async fn basic_statistics(&self) -> BasicStatistics
Sourceimpl<S: ScannerImpl> Scanner<S>
impl<S: ScannerImpl> Scanner<S>
pub fn logs<'a>(&'a self) -> Box<dyn Iterator<Item = &'a CtLog> + 'a>
pub fn new<F: Fn() -> DateTime<Utc> + 'static>( config: ScannerConfig, report_store: S::ReportStore, client: S::Client, time_source: F, ) -> Self
pub fn add_log(&mut self, log: &CtLog, sth_store: S::SthStore) -> &mut Self
Sourcepub async fn refresh_all_logs(&self) -> Result<(), ScannerError>
pub async fn refresh_all_logs(&self) -> Result<(), ScannerError>
Updates all log’s STHs