pub struct Validated<T> { /* private fields */ }Expand description
Wrapper around a type to indicate, that the contained value has been validated
When wrapping a T into Validated, it means that the value has been validated and will be
trusted from now on.
Implementations