ScannerImpl

Trait ScannerImpl 

pub trait ScannerImpl {
    type Client: Client + Clone;
    type ReportStore: AsyncSearchableStore<Key = Fingerprint, Value = Report>;
    type SthStore: AsyncSearchableStore<Key = u64, Value = Validated<SignedTreeHead>>;
}
Bundle trait for Scanner

Defines the Store and Client backends to be used by the scanner

Required Associated Types

type Client: Client + Clone

Client implementation to make connections to logs to

type ReportStore: AsyncSearchableStore<Key = Fingerprint, Value = Report>

The Store type used to store cached Reports of audit results

type SthStore: AsyncSearchableStore<Key = u64, Value = Validated<SignedTreeHead>>

The Store use to store SignedTreeHeads

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors