ScannerConfigBuilder

Struct ScannerConfigBuilder 

pub struct ScannerConfigBuilder { /* private fields */ }
Builder for ScannerConfig.

Implementations

Source

impl ScannerConfigBuilder

pub fn validate_cert_chain<VALUE: Into<bool>>( &mut self, value: VALUE, ) -> &mut Self

Set whether the certificate chain should be validated by the scanner

This is generally not necessary inside a browser, as the chain has already been validated by the browser, but e.g. it might make sense when fetching the chain from a file system.

pub fn sth_freshness_threshold<VALUE: Into<Duration>>( &mut self, value: VALUE, ) -> &mut Self

A STH that is younger than this time is considered fresh an STH that is older mature

The policy evaluation requires a fresh STH to show that the log is still active If the STH against which the inclusion proof has been made is mature, it will not require additional STH validations

pub fn sth_update_threshold<VALUE: Into<Duration>>( &mut self, value: VALUE, ) -> &mut Self

If the logs newest STH is older than this time, it will attempt to fetch a fresher value

This value must not be larger than sth_freshness_theshold

pub fn build(&self) -> Result<ScannerConfig, ScannerConfigBuilderError>

Builds a new ScannerConfig.

Errors

If a required field has not been initialized.