pub struct ScannerConfigBuilder { /* private fields */ }Expand description
Builder for ScannerConfig.
Implementations
Sourceimpl ScannerConfigBuilder
impl ScannerConfigBuilder
Sourcepub fn validate_cert_chain<VALUE: Into<bool>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn validate_cert_chain<VALUE: Into<bool>>( &mut self, value: VALUE, ) -> &mut Self
Set whether the certificate chain should be validated by the scanner
This is generally not necessary inside a browser, as the chain has already been validated by the browser, but e.g. it might make sense when fetching the chain from a file system.
Sourcepub fn otlsp_url<VALUE: Into<Option<Url>>>(&mut self, value: VALUE) -> &mut Self
pub fn otlsp_url<VALUE: Into<Option<Url>>>(&mut self, value: VALUE) -> &mut Self
The url of the otlsp proxy
If unset, no proxy is used
Sourcepub fn otlsp_connection_timeout<VALUE: Into<Duration>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn otlsp_connection_timeout<VALUE: Into<Duration>>( &mut self, value: VALUE, ) -> &mut Self
Time until an otlsp connection is considered stale and will not be reused
Sourcepub fn sth_freshness_threshold<VALUE: Into<Duration>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn sth_freshness_threshold<VALUE: Into<Duration>>( &mut self, value: VALUE, ) -> &mut Self
A STH that is younger than this time is considered fresh an STH that is older mature
The policy evaluation requires a fresh STH to show that the log is still active If the STH against which the inclusion proof has been made is mature, it will not require additional STH validations
Sourcepub fn sth_update_threshold<VALUE: Into<Duration>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn sth_update_threshold<VALUE: Into<Duration>>( &mut self, value: VALUE, ) -> &mut Self
If the logs newest STH is older than this time, it will attempt to fetch a fresher value
This value must not be larger than sth_freshness_theshold
Sourcepub fn build(&self) -> Result<ScannerConfig, ScannerConfigBuilderError>
pub fn build(&self) -> Result<ScannerConfig, ScannerConfigBuilderError>