ScannerImpl

Trait ScannerImpl 

pub trait ScannerImpl {
    type Client: Client + Clone;
    type ReportStore: SearchableStore<Fingerprint, Report>;
    type SthStore: SearchableStore<u64, Validated<SignedTreeHead>>;
}
Bundle trait for Scanner

Defines the Store and Client backends to be used by the scanner

Required Associated Types

type Client: Client + Clone

Client implementation to make connections to logs to

type ReportStore: SearchableStore<Fingerprint, Report>

The Store type used to store cached Reports of audit results

type SthStore: SearchableStore<u64, Validated<SignedTreeHead>>

The Store use to store SignedTreeHeads

Implementors